@@ -98,7 +98,8 @@ class AirTouch:
         return self.groups[groupNumber];
 
     def GetSupportedCoolingModesByGroup(self, groupNumber):
-        return self.GetSupportedCoolingModesForAc(self.groups[groupNumber].BelongsToAc);
+        self.GetSupportedCoolingModesForAc(self.groups[groupNumber].BelongsToAc);
+        return self.groups[groupNumber];
 
     def GetSupportedFanSpeedsByGroup(self, groupNumber):
         return self.GetSupportedFanSpeedsForAc(self.groups[groupNumber].BelongsToAc);
